pub enum ContractError {
Std(StdError),
Unauthorized,
Expired,
OperatorApproved {
operator: String,
},
ApprovalNotFound {
operator: String,
},
InvalidToken {
token_id: u64,
},
InvalidAmount {
val: Coin,
funds: Coin,
},
CustomError {
val: String,
},
}Variants
Std(StdError)
Only authorized entities are allowed to execute.
Expired
The approvals has expired.
OperatorApproved
operator has already been approved previously.
ApprovalNotFound
No approval found for given address.
InvalidToken
Supplied token id is invalid.
InvalidAmount
Amount sent in not equal to the price of the NFT.
CustomError
Any other error not which has not been covered.