pub enum ExecuteMsg {
TransferNft {
recipient: String,
token_id: u64,
},
SendNft {
contract: String,
token_id: u64,
msg: Binary,
},
Approve {
operator: String,
token_id: u64,
expires: Option<Expiration>,
},
Revoke {
operator: String,
token_id: u64,
},
ApproveAll {
operator: String,
expires: Option<Expiration>,
},
RevokeAll {
operator: String,
},
Mint(MintMsg),
}Variants
TransferNft
Transfer is a base message to move a token to another account without triggering actions
SendNft
Send is a base message to transfer a token to a contract and trigger an action on the receiving contract.
Approve
Allows operator to transfer / send the token from the owner’s account. If expiration is set, then this allowance has a time/height limit
Revoke
Remove previously granted Approval
ApproveAll
Allows operator to transfer / send any token from the owner’s account. If expiration is set, then this allowance has a time/height limit
RevokeAll
Remove previously granted ApproveAll permission
Mint(MintMsg)
Mint a new token with the details as in MintMsg.